==> ejc-ztpcdc-impl-3.0.0-20230802.031119-153-sources.jar: com/ejianc/business/dc/bean/DcLssueAddressBookDetailEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 签发通讯录-明细
 * 
 * @author generator
 * 
 */
 @TableName("dc_lssue_address_book_detail")
public class DcLssueAddressBookDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="address_book_id")
    private Long addressBookId; // 签发通讯录ID
    @TableField(value="receive_dept_name")
    private String receiveDeptName; // 接收人部门名称
    @TableField(value="receive_user_id")
    private Long receiveUserId; // 接收人员id
    @TableField(value="receive_user_code")
    private String receiveUserCode; // 接收人编号
    @TableField(value="receive_user_name")
    private String receiveUserName; // 接收人姓名
    @TableField(value="num")
    private Integer num; // 份数
    @TableField(value="transactor_type")
    private String transactorType; // 主办/协办--字典lssue_address_book_detail_zxb
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态


    public Long getAddressBookId() {
        return addressBookId;
    }

    public void setAddressBookId(Long addressBookId) {
        this.addressBookId = addressBookId;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }
    public Long getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getTransactorType() {
        return transactorType;
    }

    public void setTransactorType(String transactorType) {
        this.transactorType = transactorType;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
}

==> ejc-ztpcdc-impl-3.0.0-20240307.064152-295-sources.jar: com/ejianc/business/dc/bean/DcLssueAddressBookDetailEntity.java <==
package com.ejianc.business.dc.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 签发通讯录-明细
 * 
 * @author generator
 * 
 */
 @TableName("dc_lssue_address_book_detail")
public class DcLssueAddressBookDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="address_book_id")
    private Long addressBookId; // 签发通讯录ID
    @TableField(value="receive_dept_name")
    private String receiveDeptName; // 接收人部门名称
    @TableField(value="receive_user_id")
    private Long receiveUserId; // 接收人员id
    @TableField(value="receive_user_code")
    private String receiveUserCode; // 接收人编号
    @TableField(value="receive_user_name")
    private String receiveUserName; // 接收人姓名
    @TableField(value="num")
    private Integer num; // 份数
    @TableField(value="code")
    private String code; // 单据编号
    @TableField(value="name")
    private String name; // 单据名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="host_flag")
    private String hostFlag; // 主办/协办（Y为主办，N为协办）


    public Long getAddressBookId() {
        return addressBookId;
    }

    public void setAddressBookId(Long addressBookId) {
        this.addressBookId = addressBookId;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }
    public Long getReceiveUserId() {
        return receiveUserId;
    }

    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getHostFlag() {
        return hostFlag;
    }

    public void setHostFlag(String hostFlag) {
        this.hostFlag = hostFlag;
    }
}
